package cn.com.infosec.asn1.pkcs;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1OctetString;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.BERSequence;
import cn.com.infosec.asn1.BERTaggedObject;
import cn.com.infosec.asn1.DEREncodable;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.DERTaggedObject;
import cn.com.infosec.asn1.x509.AlgorithmIdentifier;

public class EncryptedData extends ASN1Encodable {
   ASN1Sequence data;
   DERObjectIdentifier bagId;
   DERObject bagValue;

   public static EncryptedData getInstance(Object obj) {
      if (obj instanceof EncryptedData) {
         return (EncryptedData)obj;
      } else if (obj instanceof ASN1Sequence) {
         return new EncryptedData((ASN1Sequence)obj);
      } else {
         throw new IllegalArgumentException("unknown object in factory: " + obj.getClass().getName());
      }
   }

   public EncryptedData(ASN1Sequence seq) {
      if (((DERInteger)seq.getObjectAt(0)).getValue().intValue() == 0) {
         this.data = (ASN1Sequence)seq.getObjectAt(1);
      } else {
         throw new IllegalArgumentException("sequence not version 0");
      }
   }

   public EncryptedData(DERObjectIdentifier contentType, AlgorithmIdentifier encryptionAlgorithm, DEREncodable content) {
      EncryptedData var10000 = this;
      super();
      ASN1EncodableVector var4;
      ASN1EncodableVector var10001 = var4 = new ASN1EncodableVector;
      var4.<init>();
      var4.add(contentType);
      var10001.add(encryptionAlgorithm.getDERObject());
      var10001.add(new BERTaggedObject(false, 0, content));
      var10000.data = new BERSequence(var4);
   }

   public DERObjectIdentifier getContentType() {
      return (DERObjectIdentifier)this.data.getObjectAt(0);
   }

   public AlgorithmIdentifier getEncryptionAlgorithm() {
      return AlgorithmIdentifier.getInstance(this.data.getObjectAt(1));
   }

   public ASN1OctetString getContent() {
      return this.data.size() == 3 ? ASN1OctetString.getInstance(((DERTaggedObject)this.data.getObjectAt(2)).getObject()) : null;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10000 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var1.add(new DERInteger(0));
      var10000.add(this.data);
      return new BERSequence(var1);
   }
}
